#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 project-template
version:              0.2.1.0
visibility:           public
id:                   project-template-0.2.1.0-1NpMoxxXNvX8B58n7hBuOK
key:                  project-template-0.2.1.0-1NpMoxxXNvX8B58n7hBuOK
license:              BSD-3-Clause
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/haskell-ide
synopsis:             Specify Haskell project templates and generate files
description:
    See initial blog post for explanation: <http://www.yesodweb.com/blog/2012/09/project-templates>

category:             Development
abi:                  9c1f9e3af23714da803d72059cc9d73d
exposed:              True
exposed-modules:      Text.ProjectTemplate
import-dirs:          /usr/lib/ghc-9.6.6/site-local/project-template-0.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/project-template-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/project-template-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-project-template
hs-libraries:         HSproject-template-0.2.1.0-1NpMoxxXNvX8B58n7hBuOK
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-6srVB7ZKmzD1HZV2AV5j9d
    bytestring-0.11.5.3 conduit-1.3.6.1-4cc2yOSL2sy5iK6rZQd5vm
    conduit-extra-1.3.8-KyGJKsBlxeR6aLyGVSa94z containers-0.6.7
    directory-1.3.8.5 filepath-1.4.300.1 mtl-2.3.1
    resourcet-1.2.6-Dhf0zTJRCL3LnKPExtEFW6 text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-project-template/html/project-template.haddock

haddock-html:         /usr/share/doc/haskell-project-template/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

